%bcond_with audacious
%bcond_with nvidia
%bcond_without wlan

Name:           conky
Version:        1.10.6
Release:        %mkrel 1
Summary:        A lightweight system monitor
License:        GPLv3+
Group:          Monitoring
Url:            https://github.com/brndnmtthws/conky
Source0:        https://github.com/brndnmtthws/conky/archive/v%{version}.tar.gz#/conky-%{version}.tar.gz
Patch1:         conky-1.10.1-fix-cmake-build.patch
BuildRequires:  cmake
BuildRequires:  docbook-style-xsl
BuildRequires:  docbook2x
BuildRequires:  git
BuildRequires:  man
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  libxslt-proc
BuildRequires:  libiw-devel
BuildRequires:  lua5.1-devel
BuildRequires:  tolua++-devel
BuildRequires:  pkgconfig(imlib2)
BuildRequires:  gettext-devel
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(ncurses)
%{?with_nvidia:BuildRequires: libXNVCtrl-devel}
%{?with_wlan:BuildRequires: wireless-tools}
# There is no audclient beginning with audacious 3.5
# which is our current cauldron one and compilation
# fails. Disable audacious support until it is fixed by upstream.
%{?with_audacious:BuildRequires:        pkgconfig(dbus-glib-1) pkgconfig(audacious)}
BuildRequires:  pkgconfig(alsa)
# std::exception_ptr does not exist on ARMv5
ExcludeArch:	armv5tl

%description
Conky is a free, light-weight system monitor for X,
that displays any information on your desktop.

%prep
%setup -q
%autopatch -p1

# remove -Werror from CFLAGS
sed -i 's|-Werror||' cmake/ConkyBuildOptions.cmake

# remove executable bits from files included in %{_docdir}
chmod a-x extras/convert.lua

for i in AUTHORS; do
    iconv -f iso8859-1 -t utf8 -o ${i}{_,} && touch -r ${i}{,_} && mv -f ${i}{_,}
done

%build
%cmake \
        -DMAINTAINER_MODE=ON \
        -DBUILD_BUILTIN_CONFIG=OFF \
        -DBUILD_PORT_MONITORS=OFF \
        -DBUILD_CURL=ON \
        -DBUILD_IBM=OFF \
        -DBUILD_IMLIB2=ON \
        -DBUILD_LUA_CAIRO=ON \
        -DBUILD_LUA_IMLIB2=ON \
        -DBUILD_MOC=OFF \
        -DBUILD_MPD=OFF \
        -DBUILD_NCURSES=OFF \
        -DBUILD_RSS=ON \
        -DBUILD_WEATHER_METAR=ON \
        -DBUILD_WEATHER_XOAP=ON \
        -DBUILD_XDBE=ON \
    %{?with_audacious:      -DBUILD_AUDACIOUS=ON} \
    %{?with_nvidia:         -DBUILD_NVIDIA=ON} \
    %{?with_wlan:           -DBUILD_WLAN=ON} \

%make_build

%install
pushd build
%make_install
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/conky
popd
install -m644 -p data/conky.conf $RPM_BUILD_ROOT%{_sysconfdir}/conky
rm -rf $RPM_BUILD_ROOT%{_docdir}/conky-*

%files
%doc AUTHORS COPYING README.md extras/*
%dir %{_sysconfdir}/conky
%config %{_sysconfdir}/conky/conky.conf
%{_bindir}/conky
%{_libdir}/conky
%{_mandir}/man1/conky.1*


%changelog
* Sat Jan 14 2017 shlomif <shlomif> 1.10.6-1.mga6
+ Revision: 1081637
- New upstream version 1.10.6.

* Sat Sep 24 2016 shlomif <shlomif> 1.10.4-1.mga6
+ Revision: 1055834
- New version 1.10.4.

* Sat May 28 2016 shlomif <shlomif> 1.10.2-1.mga6
+ Revision: 1019185
- Add missing BR
- New version 1.10.2

* Sun Feb 14 2016 umeabot <umeabot> 1.10.1-3.mga6
+ Revision: 959814
- Mageia 6 Mass Rebuild

* Thu Jan 14 2016 pterjan <pterjan> 1.10.1-2.mga6
+ Revision: 922914
- Disable on ARMv5

* Mon Dec 21 2015 shlomif <shlomif> 1.10.1-1.mga6
+ Revision: 913283
- Add missing BR
- Add missing BR
- Add missing BR
- Add missing BR
- New version 1.10.1 (10x to Fedora for some changes).

* Tue Oct 27 2015 daviddavid <daviddavid> 1.9.0-11.mga6
+ Revision: 895743
- remove empty lang files to fix build with latest rpm

* Wed Oct 15 2014 umeabot <umeabot> 1.9.0-10.mga5
+ Revision: 748062
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 1.9.0-9.mga5
+ Revision: 693669
- Rebuild to fix library dependencies

* Thu Sep 18 2014 luigiwalser <luigiwalser> 1.9.0-8.mga5
+ Revision: 693282
- fix lua BR (should be 5.1)

  + umeabot <umeabot>
    - Mageia 5 Mass Rebuild

  + tv <tv>
    - rebuild with lua-5.2

* Sat Jun 28 2014 tarakbumba <tarakbumba> 1.9.0-6.mga5
+ Revision: 640565
- Fix BR and alsa support
- Disable audacious support which is currently broken

* Fri Oct 18 2013 umeabot <umeabot> 1.9.0-5.mga4
+ Revision: 521049
- Mageia 4 Mass Rebuild

* Wed Jan 16 2013 cjw <cjw> 1.9.0-4.mga3
+ Revision: 388492
- use lua5.1 because of tolua++

* Fri Jan 11 2013 umeabot <umeabot> 1.9.0-3.mga3
+ Revision: 348114
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 11 2013 fwang <fwang> 1.9.0-2.mga3
+ Revision: 345488
- rebuild for new iw

* Wed Oct 24 2012 fwang <fwang> 1.9.0-1.mga3
+ Revision: 309599
- new version 1.9.0

* Wed Jan 11 2012 doktor5000 <doktor5000> 1.8.1-3.mga2
+ Revision: 194957
- add missing BuildRequires on dbus-glib-1
- fix CVE-2011-3616, privilege escalation vulnerability due to an insecure
  temporary file in Eve Online plugin (fix-race-condidition.patch, from Debian)

* Fri Oct 21 2011 doktor5000 <doktor5000> 1.8.1-2.mga2
+ Revision: 157291
- fix missing curl/types.h compile problem (curl-types.patch)
- added BuildRequires on audacious-devel
- enabled support for the following features:
  o Audacious
  o Weather (METAR)
  o Weather (XOAP)
  o Eve-Online skill monitor
- explicitly enable/disable all features

* Sat Mar 26 2011 kharec <kharec> 1.8.1-1.mga1
+ Revision: 77696
- imported package conky

